RingContext

Struct RingContext 

pub struct RingContext<S: RingSuite> {
    pub piop_params: PiopParams<S>,
}
Lightweight ring proof context.

Contains only the PIOP parameters needed to construct prover and verifier instances from pre-built keys, without the KZG SRS required for key generation.

Cheap to construct from a ring size alone via RingContext::new, or extractable from a RingSetup via RingSetup::ring_context.

Fields

piop_params: PiopParams<S>

PIOP parameters.

Implementations

Source

impl<S: RingSuite> RingContext<S>

pub fn new(ring_size: usize) -> Self

Construct context for the given ring size.

pub fn max_ring_size(&self) -> usize

The max ring size this context is able to handle.

pub fn ring_prover( &self, prover_key: RingProverKey<S>, key_index: usize, ) -> RingProver<S>

Create a prover instance for a specific position in the ring.

pub fn ring_verifier(&self, verifier_key: RingVerifierKey<S>) -> RingVerifier<S>

Create a verifier instance from a verifier key.

pub fn into_ring_prover( self, prover_key: RingProverKey<S>, key_index: usize, ) -> RingProver<S>

Create a prover instance, consuming the context to avoid cloning.

pub fn into_ring_verifier( self, verifier_key: RingVerifierKey<S>, ) -> RingVerifier<S>

Create a verifier instance, consuming the context to avoid cloning.