RingProofParams

Struct RingProofParams 

pub struct RingProofParams<S: RingSuite> {
    pub pcs: PcsParams<S>,
    pub piop: PiopParams<S>,
}
Ring proof parameters.

Contains the cryptographic parameters needed for ring proof generation and verification:

  • pcs: Polynomial Commitment Scheme parameters (KZG setup)
  • piop: Polynomial Interactive Oracle Proof parameters

Fields

pcs: PcsParams<S>

PCS parameters.

piop: PiopParams<S>

PIOP parameters.

Implementations

Source

impl<S: RingSuite> RingProofParams<S>

pub fn from_seed(ring_size: usize, seed: [u8; 32]) -> Self

Construct deterministic ring proof params for the given ring size.

Creates parameters using a transcript-based RNG seeded with seed.

pub fn from_rand(ring_size: usize, rng: &mut impl RngCore) -> Self

Construct random ring proof params for the given ring size.

Generates a new KZG setup with sufficient degree to support the specified ring size.

pub fn from_pcs_params( ring_size: usize, pcs_params: PcsParams<S>, ) -> Result<Self, Error>

Construct ring proof params from existing KZG setup.

Truncates the setup if larger than needed, or returns an error if it is insufficient for the specified ring size.

pub fn max_ring_size(&self) -> usize

The max ring size these parameters are able to handle.

pub fn prover_key( &self, pks: &[AffinePoint<S>], ) -> Result<RingProverKey<S>, Error>

Create a prover key for the given ring of public keys.

Returns Error::InvalidData if pks exceeds Self::max_ring_size.

pub fn prover( &self, prover_key: RingProverKey<S>, key_index: usize, ) -> RingProver<S>

Create a prover instance for a specific position in the ring.

pub fn verifier_key( &self, pks: &[AffinePoint<S>], ) -> Result<RingVerifierKey<S>, Error>

Create a verifier key for the given ring of public keys.

Returns Error::InvalidData if pks exceeds Self::max_ring_size.

pub fn verifier_key_from_commitment( &self, commitment: RingCommitment<S>, ) -> RingVerifierKey<S>

Create a verifier key from a precomputed ring commitment.

The commitment can be obtained from an existing verifier key via RingVerifierKey::commitment.

pub fn verifier_key_builder( &self, ) -> (VerifierKeyBuilder<S>, RingBuilderPcsParams<S>)

Create a builder for incremental construction of the verifier key.

pub fn verifier(&self, verifier_key: RingVerifierKey<S>) -> RingVerifier<S>

Create a verifier instance from a verifier key.

pub fn verifier_no_context( verifier_key: RingVerifierKey<S>, ring_size: usize, ) -> RingVerifier<S>

Create a verifier instance without requiring the full parameters.

Computes necessary PIOP parameters on-the-fly from the ring size rather than reusing the ones stored in self.

pub const fn padding_point() -> AffinePoint<S>

Get the padding point.

This is a point of unknown dlog that can be used in place of any key during ring construction.