pub struct Output<S: Suite>(pub AffinePoint<S>);Expand description
VRF output point generic over the cipher suite.
Elliptic curve point representing the VRF output.
Tuple Fields
0: AffinePoint<S>Implementations
Sourceimpl<S: Suite> Output<S>
impl<S: Suite> Output<S>
Sourcepub fn from_affine(value: AffinePoint<S>) -> Result<Self, Error>
pub fn from_affine(value: AffinePoint<S>) -> Result<Self, Error>
Construct from an affine point with validation.
Returns Error::InvalidData if the point is not in the prime-order
subgroup or is the group identity.
Sourcepub fn from_affine_unchecked(value: AffinePoint<S>) -> Self
pub fn from_affine_unchecked(value: AffinePoint<S>) -> Self
Construct from an affine point without validation.
The caller must ensure value is in the prime-order subgroup and is not
the group identity.