Module thin

Module thin 

Thin VRF

Same structure as Tiny VRF but produces an (R, s) proof storing the nonce commitment rather than the challenge. This enables batch verification at the cost of a slightly larger proof.

Usage

use ark_vrf::suites::bandersnatch::*;
use ark_vrf::thin::{Prover, Verifier};

let secret = Secret::from_seed([0; 32]);
let public = secret.public();
let input = Input::new(b"example input").unwrap();
let io = secret.vrf_io(input);

// Proving
let proof = secret.prove(io, b"aux data");

// Verification
let result = public.verify(io, b"aux data", &proof);

Structs

BatchItem
Deferred Thin VRF verification data for batch verification.
BatchVerifier
Batch verifier for Thin VRF proofs.
Proof
Thin VRF proof.

Traits

Prover
Trait for types that can generate Thin VRF proofs.
ThinVrfSuite
Marker trait for suites that support the Thin VRF scheme.
Verifier
Trait for entities that can verify Thin VRF proofs.