pub struct RingContext<S: RingSuite> {
pub piop_params: PiopParams<S>,
}Expand description
Lightweight ring proof context.
Contains only the PIOP parameters needed to construct prover and verifier instances from pre-built keys, without the KZG SRS required for key generation.
Cheap to construct from a ring size alone via RingContext::new, or
extractable from a RingSetup via RingSetup::ring_context.
Fields
piop_params: PiopParams<S>PIOP parameters.
Implementations
Sourceimpl<S: RingSuite> RingContext<S>
impl<S: RingSuite> RingContext<S>
Sourcepub fn max_ring_size(&self) -> usize
pub fn max_ring_size(&self) -> usize
The max ring size this context is able to handle.
Sourcepub fn ring_prover(
&self,
prover_key: RingProverKey<S>,
key_index: usize,
) -> RingProver<S>
pub fn ring_prover( &self, prover_key: RingProverKey<S>, key_index: usize, ) -> RingProver<S>
Create a prover instance for a specific position in the ring.
Sourcepub fn ring_verifier(&self, verifier_key: RingVerifierKey<S>) -> RingVerifier<S>
pub fn ring_verifier(&self, verifier_key: RingVerifierKey<S>) -> RingVerifier<S>
Create a verifier instance from a verifier key.
Sourcepub fn into_ring_prover(
self,
prover_key: RingProverKey<S>,
key_index: usize,
) -> RingProver<S>
pub fn into_ring_prover( self, prover_key: RingProverKey<S>, key_index: usize, ) -> RingProver<S>
Create a prover instance, consuming the context to avoid cloning.
Sourcepub fn into_ring_verifier(
self,
verifier_key: RingVerifierKey<S>,
) -> RingVerifier<S>
pub fn into_ring_verifier( self, verifier_key: RingVerifierKey<S>, ) -> RingVerifier<S>
Create a verifier instance, consuming the context to avoid cloning.