pub struct RingSetup<S: RingSuite> {
pub pcs_params: PcsParams<S>,
pub ring_ctx: RingContext<S>,
}Expand description
Ring proof setup.
Contains the cryptographic parameters needed for ring proof key construction, proving and verification:
pcs_params: Polynomial Commitment Scheme parameters (KZG setup)ring_ctx: Ring context containing the PIOP parameters
Fields
pcs_params: PcsParams<S>PCS parameters.
ring_ctx: RingContext<S>Ring context (PIOP parameters).
Implementations
Sourceimpl<S: RingSuite> RingSetup<S>
impl<S: RingSuite> RingSetup<S>
Sourcepub fn from_seed(ring_size: usize, seed: [u8; 32]) -> Self
pub fn from_seed(ring_size: usize, seed: [u8; 32]) -> Self
Construct deterministic ring proof params for the given ring size.
Creates parameters using a transcript-based RNG seeded with seed.
Sourcepub fn from_rand(ring_size: usize, rng: &mut impl RngCore) -> Self
pub fn from_rand(ring_size: usize, rng: &mut impl RngCore) -> Self
Construct random ring proof params for the given ring size.
Generates a new KZG setup with sufficient degree to support the specified ring size.
Sourcepub fn from_pcs_params(
ring_size: usize,
pcs_params: PcsParams<S>,
) -> Result<Self, Error>
pub fn from_pcs_params( ring_size: usize, pcs_params: PcsParams<S>, ) -> Result<Self, Error>
Construct ring proof params from existing KZG setup.
Truncates the setup if larger than needed, or returns
Error::RingCapacityExceeded if it is insufficient for the specified ring size.
Sourcepub fn prover_key(
&self,
pks: &[AffinePoint<S>],
) -> Result<RingProverKey<S>, Error>
pub fn prover_key( &self, pks: &[AffinePoint<S>], ) -> Result<RingProverKey<S>, Error>
Create a prover key for the given ring of public keys.
Returns Error::RingCapacityExceeded if pks exceeds the max ring size,
Error::InvalidData if a key cannot be mapped to Twisted Edwards form.
Sourcepub fn verifier_key(
&self,
pks: &[AffinePoint<S>],
) -> Result<RingVerifierKey<S>, Error>
pub fn verifier_key( &self, pks: &[AffinePoint<S>], ) -> Result<RingVerifierKey<S>, Error>
Create a verifier key for the given ring of public keys.
Returns Error::RingCapacityExceeded if pks exceeds the max ring size,
Error::InvalidData if a key cannot be mapped to Twisted Edwards form.
Sourcepub fn verifier_key_from_commitment(
&self,
commitment: RingCommitment<S>,
) -> RingVerifierKey<S>
pub fn verifier_key_from_commitment( &self, commitment: RingCommitment<S>, ) -> RingVerifierKey<S>
Create a verifier key from a precomputed ring commitment.
The commitment can be obtained from an existing verifier key via
RingVerifierKey::commitment.
Sourcepub fn pcs_verifier_params(&self) -> PcsVerifierParams<S>
pub fn pcs_verifier_params(&self) -> PcsVerifierParams<S>
Extract the PCS parameters required by the verifier.
Small (a few points) and independent of ring size. Sufficient,
together with a ring commitment, to reconstruct a verifier key via
verifier_key_from_commitment without access to the full setup.
Sourcepub fn verifier_key_builder(
&self,
) -> (VerifierKeyBuilder<S>, RingBuilderPcsParams<S>)
pub fn verifier_key_builder( &self, ) -> (VerifierKeyBuilder<S>, RingBuilderPcsParams<S>)
Create a builder for incremental construction of the verifier key.
Sourcepub fn ring_context(&self) -> &RingContext<S>
pub fn ring_context(&self) -> &RingContext<S>
Get a reference to the lightweight RingContext.
Sourcepub const fn padding_point() -> AffinePoint<S>
pub const fn padding_point() -> AffinePoint<S>
Get the padding point.
This is a point of unknown dlog that can be used in place of any key during ring construction.
Methods from Deref<Target = RingContext<S>>
Sourcepub fn max_ring_size(&self) -> usize
pub fn max_ring_size(&self) -> usize
The max ring size this context is able to handle.
Sourcepub fn ring_prover(
&self,
prover_key: RingProverKey<S>,
key_index: usize,
) -> RingProver<S>
pub fn ring_prover( &self, prover_key: RingProverKey<S>, key_index: usize, ) -> RingProver<S>
Create a prover instance for a specific position in the ring.
Sourcepub fn ring_verifier(&self, verifier_key: RingVerifierKey<S>) -> RingVerifier<S>
pub fn ring_verifier(&self, verifier_key: RingVerifierKey<S>) -> RingVerifier<S>
Create a verifier instance from a verifier key.