pub trait MapConfig:
TECurveConfig
+ SWCurveConfig
+ MontCurveConfig {
const MONT_A_OVER_THREE: <Self as CurveConfig>::BaseField;
const MONT_B_INV: <Self as CurveConfig>::BaseField;
}Expand description
Constants used in mapping TE form to SW form and vice versa. Configuration trait for curves that support mapping between representations.
This trait must be implemented for curves that need to be converted between Twisted Edwards, Short Weierstrass, and Montgomery forms.
Required Associated Constants
Sourceconst MONT_A_OVER_THREE: <Self as CurveConfig>::BaseField
const MONT_A_OVER_THREE: <Self as CurveConfig>::BaseField
Precomputed value of Montgomery curve parameter A divided by 3.
Sourceconst MONT_B_INV: <Self as CurveConfig>::BaseField
const MONT_B_INV: <Self as CurveConfig>::BaseField
Precomputed inverse of Montgomery curve parameter B.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.